Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

[0.1.0] - 2024-XX-XX
--------------------

Added
~~~~~

* Initial release
* Chat API support with streaming
* Embedding API support
* Rerank API support
* Tokenizer support (optional dependency on transformers)
* Unified Usage and ResultBase classes
* Comprehensive test suite
* Documentation

